@@ -34,7 +34,7 @@ class Builtins(FluxCog):
       "member"     : "member",
    }
 
-   def load(self):
+   def load(self) -> None:
       async def parse_auth_id(ctx: GuildAwareCtx, type_: str, target_: str) -> int:
          if type_ == "member":
             ids_ = utils.find_mentions(target_)
@@ -169,7 +169,7 @@ class Builtins(FluxCog):
          setprefix prefix
          ==
          Sets the bot prefix to `prefix`
-         Ignores surrounding whitespace. Please don't.
+         Ignores surrounding whitespace.
          ==
          prefix: The string to put before a command name. Strips leading and trailing spaces.
          ==
@@ -181,6 +181,7 @@ class Builtins(FluxCog):
             cfg["prefix"] = prefix.strip()
          return Response()
 
+      # noinspection PyUnresolvedReferences
       @self._commandeer(name="exec", override_auths=[Record.deny_all()])
       async def __exec(ctx: CommandCtx, script: str):
          """
@@ -194,23 +195,32 @@ class Builtins(FluxCog):
          :param script:
          :return:
          """
+         from pprint import pformat
+
          exec_func = utils.sexec
          if "await " in script:
             exec_func = utils.aexec
 
+         # Utils for exec
+         from .. import context
+         # ==
+         _c = ctx.msg_ctx.dest
+         _d = discord
+         _g: discord.Guild = ctx.msg_ctx.message.guild
+         _b = _g.me
          with utils.Timer() as t:
             # noinspection PyBroadException
             try:
                res = await exec_func(script, globals(), locals())
             except Exception as e:
                res = re.sub(r'File ".*[\\/]([^\\/]+.py)"', r'File "\1"', traceback.format_exc(limit=1))
+            res = res.replace(r"/home/zenith/.cache/pypoetry/virtualenvs/pinbot-AoGbOYTv-py3.9/lib/python3.9/site-packages", "...")
 
-         return Response((f""
-                          f"Ran in {t.elapsed * 1000:.2f} ms\n"
+         return Response((f"Ran in {t.elapsed * 1000:.2f} ms\n"
                           f"**IN**:\n"
-                          f"```py\n{script}\n```\n"
+                          f"```py\n{script}\n```"
                           f"**OUT**:\n"
-                          f"```py\n{res}\n```"), trashable=True)
+                          f"```py\n{pformat(res)}\n```"), trashable=True)
 
       @self._commandeer(name="auth", default_auths=[Record.allow_server_manager()])
       async def __auth(ctx: GuildCommandCtx, auth_str):
