@@ -163,7 +163,7 @@ class MessageCtx(AuthAwareCtx, AuthorAwareCtx, metaclass=ABCMeta):
 
 class GuildTextChannelCtx(GuildAwareCtx, _MessageableCtx):
 
-   def __init__(self, flux: FluxClient, channel: discord.TextChannel, **kwargs):
+   def __init__(self, flux: FluxClient, channel: discord.TextChannel, **kwargs: ty.Any):
       super().__init__(flux=flux, **kwargs)
       self.channel = channel
 
