@@ -113,12 +113,12 @@ class FluxClient(discord.Client):
          logger.success("Discord.py is ready")
 
       @self.router.listen_for(":guild_join")
-      async def _(g: discord.Guild):
-         logger.info(f"Joined guild: {g}")
+      async def _(ev: FluxEvent):
+         logger.info(f"Joined guild: {ev.args[0]}")
 
       @self.router.listen_for(":guild_remove")
-      async def _(g: discord.Guild):
-         logger.info(f"Removed from guild: {g}")
+      async def _(ev: FluxEvent):
+         logger.info(f"Removed from guild: {ev.args[0]}")
 
    async def get_user_s(self, user_id: int) -> ty.Optional[discord.User]:
       try:
@@ -139,3 +139,18 @@ class FluxClient(discord.Client):
          return self.get_channel(id_) or await self.fetch_channel(id_)
       except (discord.NotFound, discord.Forbidden, discord.HTTPException):
          return None
+
+
+class FluxCore(aur.AurCore):
+   def __init__(self, name: str, admin_id: int, status: str = None, intents: discord.Intents = None):
+      super(FluxCore, self).__init__(name)
+      self.flux = FluxClient(name=name, admin_id=admin_id, parent_router=self.router, status=status, intents=intents)
+
+   async def startup(self, token: str, *args: ty.Any, **kwargs: ty.Any) -> None:
+      await super(FluxCore, self).startup(*args, **kwargs)
+      await self.flux.start(token)
+
+   async def shutdown(self, *args: ty.Any, **kwargs: ty.Any) -> None:
+      await super(FluxCore, self).shutdown(*args, **kwargs)
+      await self.flux.logout()
+      await self.flux.aiohttp_session.close()
